@@ -45,7 +45,7 @@ class Firebase:
         self._authenticate()
         url = f"{self.agent_config.url(db_alias)}.json"
         check_argument(len(file_paths) > 0, "Unable to upload file_paths (zero size).")
-        log.debug('Uploading files  alias=%s  files=%s', db_alias, ','.join(file_paths))
+        log.debug('Uploading files  alias=%s  files=[%s]', db_alias, ','.join(file_paths))
         return self.processor.upload_files(url, file_paths, glob_exp) > 0
 
     def download(self, db_alias: str, dest_dir: str) -> bool:
